function [x,y]=henon(ah,bh,x0,y0,np)
%	[x,y]=henon(ah,bh,x0,y0,np)
%	np=desired number of points
%	x(n=1) = 1 - ah*x(n)^2 + y(n)
%	y(n+1) = bh*x(n)
%	Chaotic behavior occurs for ah=1.4, bh=0.3
%
%	This program is distributed as a supplement to the book
%	"Biomedical Signal Processing and Signal Modeling" by E. N. Bruce,
%	published by Wiley, 2000.  It is provided for educational use only.
%  While every effort has been made to insure its suitability to illustrate
%  principles described in the above book, no specific feature or capability 
%  is implied or guaranteed.
x(1)=x0;
y(1)=y0;
for k=2:np
	y(k)=bh*x(k-1);
	x(k)=y(k-1)+1-ah*x(k-1)*x(k-1);
end

