function [ret,x0,str,ts,xts]=info9(t,x,u,flag);
%INFO9	is the M-file description of the SIMULINK system named INFO9.
%	The block-diagram can be displayed by typing: INFO9.
%
%	SYS=INFO9(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes INFO9 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling INFO9 with a FLAG of zero:
%	[SIZES]=INFO9([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[239,59,739,359])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Info on hrv'.

new_system([sys,'/','Info on hrv'])
set_param([sys,'/','Info on hrv'],'Location',[40,260,290,385])

add_block('built-in/Note',[sys,'/',['Info on hrv/Information on hrv:',13,'Beat by beat heart rate.',13,'10 channels (columns) of',13,'256 beats.']])
set_param([sys,'/',['Info on hrv/Information on hrv:',13,'Beat by beat heart rate.',13,'10 channels (columns) of',13,'256 beats.']],...
		'position',[115,25,120,30])
set_param([sys,'/','Info on hrv'],...
		'Mask Display','')


%     Finished composite block 'Info on hrv'.

set_param([sys,'/','Info on hrv'],...
		'ForeGround',3,...
		'BackGround',3,...
		'position',[80,67,110,117])


%     Subsystem  'Info on eegspike'.

new_system([sys,'/','Info on eegspike'])
set_param([sys,'/','Info on eegspike'],'Location',[40,260,290,385])

add_block('built-in/Note',[sys,'/',['Info on eegspike/Information about eegspike:',13,'One eeg channel',13,'sampled at 67.5 Hz.',13,'Total of 1024 points.']])
set_param([sys,'/',['Info on eegspike/Information about eegspike:',13,'One eeg channel',13,'sampled at 67.5 Hz.',13,'Total of 1024 points.']],...
		'position',[130,25,135,30])
set_param([sys,'/','Info on eegspike'],...
		'Mask Display','')


%     Finished composite block 'Info on eegspike'.

set_param([sys,'/','Info on eegspike'],...
		'ForeGround',5,...
		'BackGround',5,...
		'position',[205,67,235,117])

add_block('built-in/Note',[sys,'/','DOUBLE-CLICK ON ANY BOX:'])
set_param([sys,'/','DOUBLE-CLICK ON ANY BOX:'],...
		'position',[155,15,160,20])


%     Subsystem  'Info on ranproc2'.

new_system([sys,'/','Info on ranproc2'])
set_param([sys,'/','Info on ranproc2'],'Location',[40,260,290,385])

add_block('built-in/Note',[sys,'/',['Info on ranproc2/Eight channels (columns) of airflow from',13,'anesthetized rats, sampled',13,'at 75.0 Hz.',13,' 2048 data points per',13,'column.']])
set_param([sys,'/',['Info on ranproc2/Eight channels (columns) of airflow from',13,'anesthetized rats, sampled',13,'at 75.0 Hz.',13,' 2048 data points per',13,'column.']],...
		'position',[120,20,125,25])
set_param([sys,'/','Info on ranproc2'],...
		'Mask Display','')


%     Finished composite block 'Info on ranproc2'.

set_param([sys,'/','Info on ranproc2'],...
		'BackGround',0,...
		'position',[85,157,115,207])


%     Subsystem  'Info on ranproc3'.

new_system([sys,'/','Info on ranproc3'])
set_param([sys,'/','Info on ranproc3'],'Location',[40,260,382,385])

add_block('built-in/Note',[sys,'/',['Info on ranproc3/Eight channels (columns) of EMG from the',13,'genioglossus muscle of an awake human,',13,'obtained during 8 forward tongue thrusts.',13,'256 points per channel, sampled',13,'at 500 Hz.']])
set_param([sys,'/',['Info on ranproc3/Eight channels (columns) of EMG from the',13,'genioglossus muscle of an awake human,',13,'obtained during 8 forward tongue thrusts.',13,'256 points per channel, sampled',13,'at 500 Hz.']],...
		'position',[160,20,165,25])
set_param([sys,'/','Info on ranproc3'],...
		'Mask Display','')


%     Finished composite block 'Info on ranproc3'.

set_param([sys,'/','Info on ranproc3'],...
		'ForeGround',6,...
		'BackGround',6,...
		'position',[210,157,240,207])


%     Subsystem  'Info on ma3sig'.

new_system([sys,'/','Info on ma3sig'])
set_param([sys,'/','Info on ma3sig'],'Location',[40,260,290,385])

add_block('built-in/Note',[sys,'/',['Info on ma3sig/Contains the signal xn[n] which was ',13,'used in example 9._.']])
set_param([sys,'/',['Info on ma3sig/Contains the signal xn[n] which was ',13,'used in example 9._.']],...
		'position',[120,20,125,25])
set_param([sys,'/','Info on ma3sig'],...
		'Mask Display','')


%     Finished composite block 'Info on ma3sig'.

set_param([sys,'/','Info on ma3sig'],...
		'ForeGround',7,...
		'BackGround',7,...
		'position',[325,65,355,115])


%     Subsystem  'Info on arma12'.

new_system([sys,'/','Info on arma12'])
set_param([sys,'/','Info on arma12'],'Location',[40,260,322,385])

add_block('built-in/Note',[sys,'/',['Info on arma12/The time series, yn, analyzed using an ARMA',13,'model in example 9._.',13,'atru2 and btru2 are the denominator ',13,'and numerator coefficients used to',13,'generate yn by filtering white noise.']])
set_param([sys,'/',['Info on arma12/The time series, yn, analyzed using an ARMA',13,'model in example 9._.',13,'atru2 and btru2 are the denominator ',13,'and numerator coefficients used to',13,'generate yn by filtering white noise.']],...
		'position',[140,20,145,25])
set_param([sys,'/','Info on arma12'],...
		'Mask Display','')


%     Finished composite block 'Info on arma12'.

set_param([sys,'/','Info on arma12'],...
		'ForeGround',2,...
		'BackGround',2,...
		'position',[330,155,360,205])


%     Subsystem  'Info on montage'.

new_system([sys,'/','Info on montage'])
set_param([sys,'/','Info on montage'],'Location',[40,260,382,426])

add_block('built-in/Note',[sys,'/',['Info on montage/Actual records for sleep stage analysis from a human',13,'subject.',13,'Column 1 = ECG',13,'Columns 2 -7 = 6 eeg channels',13,'Column 8 = oronasal airflow detected by thermistors',13,'placed in front of the nose and mouth',13,'355.7 seconds of data sampled at 67.5 Hz per channel']])
set_param([sys,'/',['Info on montage/Actual records for sleep stage analysis from a human',13,'subject.',13,'Column 1 = ECG',13,'Columns 2 -7 = 6 eeg channels',13,'Column 8 = oronasal airflow detected by thermistors',13,'placed in front of the nose and mouth',13,'355.7 seconds of data sampled at 67.5 Hz per channel']],...
		'position',[165,25,170,30])
set_param([sys,'/','Info on montage'],...
		'Mask Display','')


%     Finished composite block 'Info on montage'.

set_param([sys,'/','Info on montage'],...
		'ForeGround',4,...
		'BackGround',4,...
		'position',[430,65,460,115])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
