%	sigtype.m
%	The deterministic signal is a sum of 5 sine waves having
%  random amplitudes and frequencies.
%	The filtered white-noise signal is generated by passing white
%  noise through a filter given by z^2/(z^2 - 0.6 z - 0.2).
%	The fractal signal is created using the spectral synthesis method
%  with 300 frequencies and H = 0.8.
%	The chaotic signal is from the Henon system with parameters
%  1.4 and 0.3.
%
%	This program is distributed as a supplement to the book
%	"Biomedical Signal Processing and Signal Modeling" by E. N. Bruce,
%	published by Wiley, 2000.  It is provided for educational use only.
%  While every effort has been made to insure its suitability to illustrate
%  principles described in the above book, no specific feature or capability 
%  is implied or guaranteed.
p=randn(5,1); n=0:600; dt=.005;
s1=zeros(1,601);
for j=1:5
	s1=s1+p(j)*sin(2*pi*10*p(6-j)*n*dt);
end
subplot(221),plot([dt*n],s1), title('DETERMINISTIC')
b2=[1];a2=[1 -.6 -.2];
x=randn(600,1); s2=filter(b2,a2,x);
subplot(222),plot(s2(401:600)), title('FILTERED WHITE NOISE')
H=0.8;
s3=fracssm(H,300,200);
subplot(223),plot(diff(s3)); title('FRACTAL NOISE')
xz=0.3*rand(1,1);yz=0.3*rand(1,1);[s4,y]=henon(1.4,.3,xz,yz,600);
subplot(224), plot(s4(501:600)); title('CHAOTIC')
